<?php
/***********************************************************************************
*  load_morphotype_master.php                        Wagner Database Solutions, Inc.
*    v1.03 - 25 Feb 2004  (c) 2004 Steve Wagner.  All rights reserved.
*            See the PaleoCollaborator License included as license_v1.x.txt
*
*  Description:  This script is used to load the PC_Morphotype_Master.csv file.  This
*                is used to load the initial morphotypes or any subsequent large loads.
*
*  Change Log:
*    v1.0   Initial beta release
*    v1.01  Removed \" around dates for mysql.  Added test for SQL Server 
*           ErrorNo() 2627 because "Duplicate" wasn't appearing in ErrorMsg().
*    v1.02  In morphotype and specimen inserts and updates:  changed \" around
*           field to just ' to get them to load.  Also removed addslashes().
*           Also added ereg_replace() around data[8] because there were single 
*           quotes in the data like PC010 "FEV's" and PC074 "don't"
*    v1.03  Removed logic for loading PC_Load_Morphotypes.csv vs PC_Load_Attachments.csv
*           because these files have been merged for loading.
*
************************************************************************************/

include_once ("./include/config.php");
include_once ("./include/header.php");
?>
<html>
<body>

<?php

$ADODB_FETCH_MODE = ADODB_FETCH_ASSOC;

$db = ADONewConnection($driver); 
/* $db->debug = true;  #true */
$db->Connect($server, $user, $password, $database);

print "<br><b>Loading Morphotype Master Data from File: " . $filename . "</b><br>\n";

$handle = fopen ("data_import/$filename","r");

/* get and ignore first 6 rows because they are headers in the CSV file */
for ( $i = '1'; $i <= 6; $i++ ) {
  $data = fgetcsv ($handle, 4096, ",");
}

$row = 1;

while ($data = fgetcsv ($handle, 4096, ",")) {
  $num = count ($data);
  print "<BR>****** Morphotype <b>$data[0]</b>: $num fields loaded from line $row: *********** ";
  $row++;

  $data[8] = ereg_replace("'","",$data[8]);

  $timestring = substr($data[15],6,4)."-".
                substr($data[15],0,2)."-".
                substr($data[15],3,2);
  $appdate=$db->DBDATE( strftime($timestring,"%Y-%m-%d"));

  $timestring = substr($data[31],6,4)."-".
                substr($data[31],0,2)."-".
                substr($data[31],3,2);
  $createdate=$db->DBDATE( strftime($timestring,"%Y-%m-%d") ); 


  $timestring = substr($data[32],6,4)."-".
                substr($data[32],0,2)."-".
                substr($data[32],3,2);
  $lastupdatedate=$db->DBTimeStamp( strftime($timestring,"%Y-%m-%d") ); 

  /*  INSERT MORPHOTYPES ROW */
  $sql  = "INSERT INTO MORPHOTYPES (MORPHOTYPE_NBR, GENUS_NAME, SPECIES_NAME, AUTHOR, FAMILY, THE_ORDER, ";
  $sql .= "OLD_NAMES, HIGHER_TAXON, DIAGNOSTIC_FEATURES, MORPHOTYPE_TEXT, PUBLICATION_ID, PUBLICATION_HELP, ";
  $sql .= "RARITY_SCALE, APPROVED_FOR_DISPLAY, APPROVED_BY, APPROVED_DATE, LAST_UPDATE_DATE) VALUES (";
  $sql .= "\"$data[0]\",'$data[1]',\"$data[2]\",\"$data[3]\",\"$data[4]\",\"$data[5]\",\"$data[6]\",";
  $sql .= "\"$data[7]\",'$data[8]',\"$data[9]\",\"$data[10]\",\"$data[11]\",\"$data[12]\",\"$data[13]\",";
  $sql .= "\"$data[14]\", $appdate , $lastupdatedate )";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
	  print '<br>Duplicate MORPHOTYPES: ['.$db->ErrorMsg().'].  Attempting Update...';
      /*  UPDATE MORPHOTYPES ROW */
      $sql  = "UPDATE MORPHOTYPES SET GENUS_NAME = '$data[1]', SPECIES_NAME = \"$data[2]\", AUTHOR = \"$data[3]\", ";
      $sql .= "FAMILY = \"$data[4]\", THE_ORDER = \"$data[5]\", OLD_NAMES = \"$data[6]\", HIGHER_TAXON = \"$data[7]\", ";
	  $sql .= "DIAGNOSTIC_FEATURES = '$data[8]', MORPHOTYPE_TEXT = \"$data[9]\", PUBLICATION_ID = \"$data[10]\", ";
      $sql .= "PUBLICATION_HELP = \"$data[11]\", RARITY_SCALE = \"$data[12]\", APPROVED_FOR_DISPLAY = \"$data[13]\", ";
      $sql .= "APPROVED_BY = \"$data[14]\", APPROVED_DATE = $appdate, LAST_UPDATE_DATE = $lastupdatedate ";
      $sql .= "WHERE MORPHOTYPE_NBR = \"$data[0]\"; ";

      if ($db->Execute($sql) === false) {
        print "sql: " . $sql . "<br><br>\n";
	    print 'Error updating MORPHOTYPES: ['.$db->ErrorMsg().'].<BR><BR>';
	  } else {
	    print "worked!<br>\n";
	  }
    } else {
      print "sql: " . $sql . "<br><br>\n";
	  print 'Error inserting MORPHOTYPES: ['.$db->ErrorMsg().'].<BR><BR>';
	}
  }

  $timestring = substr($data[29],6,4)."-".
                substr($data[29],0,2)."-".
                substr($data[29],3,2);
  $appdate=$db->DBDATE( strftime($timestring,"%Y-%m-%d"));
  
  /*  INSERT SPECIMENS ROW */
  $sql  = "INSERT INTO SPECIMENS (SPECIMEN_NBR, MORPHOTYPE_NBR, SPECIMEN_CAT, LOC_NBR, COLLECTION_ID, ORGAN, ";
  $sql .= "COLLECTED_BY, COLLECTED_DATE, SPECIMEN_TEXT, ACQ_DATE, ACQ_FROM, ACQ_EXCHANGE,";
  $sql .= "APPROVED_FOR_DISPLAY, APPROVED_BY, APPROVED_DATE, CREATED_BY, CREATION_DATE, LAST_UPDATE_DATE) VALUES (";
  $sql .= "\"$data[16]\",\"$data[0]\",\"$data[17]\",\"$data[18]\",\"$data[19]\",'$data[20]',\"$data[21]\",";
  $sql .= "\"$data[22]\",\"$data[23]\",\"$data[24]\",\"$data[25]\",\"$data[26]\",\"$data[27]\",\"$data[28]\",";
  $sql .= "$appdate,\"$data[30]\",$createdate,$lastupdatedate)";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
	  print 'Duplicate SPECIMENS: ['.$db->ErrorMsg().'].  Attempting Update... ';
      /*  UPDATE SPECIMENS ROW */
      $sql  = "UPDATE SPECIMENS SET SPECIMEN_CAT = \"$data[17]\", LOC_NBR = \"$data[18]\", ";
      $sql .= "COLLECTION_ID = \"$data[19]\", ORGAN = '$data[20]', COLLECTED_BY = \"$data[21]\", ";
      $sql .= "COLLECTED_DATE = \"$data[22]\", SPECIMEN_TEXT = \"$data[23]\", ACQ_DATE = \"$data[24]\", ";
	  $sql .= "ACQ_FROM = \"$data[25]\", ACQ_EXCHANGE = \"$data[26]\", APPROVED_FOR_DISPLAY = \"$data[27]\", ";
      $sql .= "APPROVED_BY = \"$data[28]\", APPROVED_DATE = $appdate, CREATED_BY = \"$data[30]\", ";
	  $sql .= "CREATION_DATE = $createdate, LAST_UPDATE_DATE = $lastupdatedate ";
      $sql .= "WHERE MORPHOTYPE_NBR = \"$data[0]\" AND SPECIMEN_NBR = \"$data[16]\"; ";

      if ($db->Execute($sql) === false) {
        print "sql: " . $sql . "<br><br>\n";
	    print 'Error updating SPECIMENS: ['.$db->ErrorMsg().'].<BR><BR>';
	  } else {
	    print "worked!<br>\n";
	  }
    } else {
      print "sql: " . $sql . "<br><br>\n";
	  print 'Error inserting SPECIMENS: ['.$db->ErrorMsg().'].<BR><BR>';
	}
  }

  /*  INSERT FULL SIZE IMAGE INTO IMAGES TABLE */
  $sql  = "INSERT INTO IMAGES (MORPHOTYPE_NBR, SPECIMEN_NBR, IMAGE_TYPE, IMAGE_LOC) VALUES (";
  $sql .= "\"$data[0]\", \"$data[16]\",\"DF\",\"fossil_images/$data[35]\")";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
	  print 'Duplicate IMAGES: ['.$db->ErrorMsg().'].  Attempting Update... ';
      /*  UPDATE IMAGES ROW */
      $sql  = "UPDATE IMAGES SET IMAGE_LOC = \"fossil_images/$data[35]\" WHERE MORPHOTYPE_NBR = \"$data[0]\" AND SPECIMEN_NBR = \"$data[16]\" AND IMAGE_TYPE = \"DF\";";
      if ($db->Execute($sql) === false) {
        print "sql: " . $sql . "<br><br>\n";
	    print 'Error updating IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	  } else {
	    print "worked!<br>\n";
	  }
    } else {
      print "sql: " . $sql . "<br><br>\n";
	  print 'Error inserting IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	}
  }

  /*  INSERT DETAIL IMAGE INTO IMAGES TABLE */
  $sql  = "INSERT INTO IMAGES (MORPHOTYPE_NBR, SPECIMEN_NBR, IMAGE_TYPE, IMAGE_LOC) VALUES (";
  $sql .= "\"$data[0]\", \"$data[16]\",\"D\",\"fossil_images/$data[36]\")";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
	  print 'Duplicate IMAGES: ['.$db->ErrorMsg().'].  Attempting Update... ';
      /*  UPDATE IMAGES ROW */
      $sql  = "UPDATE IMAGES SET IMAGE_LOC = \"fossil_images/$data[36]\" WHERE MORPHOTYPE_NBR = \"$data[0]\" AND SPECIMEN_NBR = \"$data[16]\" AND IMAGE_TYPE = \"D\";";
      if ($db->Execute($sql) === false) {
        print "sql: " . $sql . "<br><br>\n";
	    print 'Error updating IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	  } else {
	    print "worked!<br>\n";
	  }
    } else {
      print "sql: " . $sql . "<br><br>\n";
	  print 'Error inserting IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	}
  }
  
  /*  INSERT THUMBNAIL IMAGE INTO IMAGES TABLE */
  $sql  = "INSERT INTO IMAGES (MORPHOTYPE_NBR, SPECIMEN_NBR, IMAGE_TYPE, IMAGE_LOC) VALUES (";
  $sql .= "\"$data[0]\", \"$data[16]\",\"T\",\"fossil_images/$data[37]\")";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
	  print 'Duplicate IMAGES: ['.$db->ErrorMsg().'].  Attempting Update... ';
      /*  UPDATE IMAGES ROW */
      $sql  = "UPDATE IMAGES SET IMAGE_LOC = \"fossil_images/$data[37]\" WHERE MORPHOTYPE_NBR = \"$data[0]\" AND SPECIMEN_NBR = \"$data[16]\" AND IMAGE_TYPE = \"T\";";
      if ($db->Execute($sql) === false) {
        print "sql: " . $sql . "<br><br>\n";
	    print 'Error updating IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	  } else {
	    print "worked!<br>\n";
	  }
    } else {
      print "sql: " . $sql . "<br><br>\n";
	  print 'Error inserting IMAGES: ['.$db->ErrorMsg().'].<BR><BR>';
	}
  }
  
  /*  INSERT INTO MORPHOTYPE CATEGORIES TABLE */
  $sql  = "INSERT INTO MORPHOTYPE_CATEGORIES (MORPHOTYPE_NBR, MENU_ID, CATEGORY_ID) VALUES (";
  $sql .= "\"$data[0]\", '', \"$data[34]\" )";

  if ($db->Execute($sql) === false) {
    if (strrchr($db->ErrorMsg(), 'Duplicate' ) or ($db->ErrorNo()=='2627' ) ) { // 2627 is mssql error #
      print 'Duplicate MORPHOTYPE_CATEGORIES: ['.$db->ErrorMsg().'].  No need to Update... <br>';
    } else {
      print "sql: " . $sql . "<br><br>\n";
      print 'Error inserting MORPHOTYPE_CATEGORIES: ['.$db->ErrorMsg().'].<BR><BR>';
    }
  }

}
fclose ($handle);

/****************************************************************************/

include ("./include/footer.php");

?>

</body>
</html>